@@ -1,2 +1,2 @@
-from .torchshow import show, show_video, save
+from .torchshow import show, show_video, save, overlay
 from .config import set_image_std, set_image_mean, set_color_mode, show_rich_info
\ No newline at end of file
